#!/bin/sh
export PATH='/sbin:/bin:/usr/sbin:/usr/bin:/usr/games:/usr/local/sbin:/usr/local/bin:/root/bin'
echo 'name: lens
version: 4.12.3
id: lens-4.12.3-e6f897116518809d00486164bd2915ae
key: lens_HrIy992mtzN5wFUKQZBmkf
license: BSD3
copyright: Copyright (C) 2012-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/lens/
synopsis: Lenses, Folds and Traversals
description:
    This package comes \"Batteries Included\" with many useful lenses for the types
    commonly used from the Haskell Platform, and with tools for automatically
    generating lenses and isomorphisms for user-supplied data types.
    .
    The combinators in @Control.Lens@ provide a highly generic toolbox for composing
    families of getters, folds, isomorphisms, traversals, setters and lenses and their
    indexed variants.
    .
    An overview, with a large number of examples can be found in the <https://github.com/ekmett/lens#lens-lenses-folds-and-traversals README>.
    .
    An introductory video on the style of code used in this library by Simon Peyton Jones is available from <http://skillsmatter.com/podcast/scala/lenses-compositional-data-access-and-manipulation Skills Matter>.
    .
    A video on how to use lenses and how they are constructed is available on <http://youtu.be/cefnmjtAolY?hd=1 youtube>.
    .
    Slides for that second talk can be obtained from <http://comonad.com/haskell/Lenses-Folds-and-Traversals-NYC.pdf comonad.com>.
    .
    More information on the care and feeding of lenses, including a brief tutorial and motivation
    for their types can be found on the <https://github.com/ekmett/lens/wiki lens wiki>.
    .
    A small game of @pong@ and other more complex examples that manage their state using lenses can be found in the <https://github.com/ekmett/lens/blob/master/examples/ example folder>.
    .
    /Lenses, Folds and Traversals/
    .
    With some signatures simplified, the core of the hierarchy of lens-like constructions looks like:
    .
    .
    <<http://i.imgur.com/ALlbPRa.png>>
    .
    <Hierarchy.png (Local Copy)>
    .
    You can compose any two elements of the hierarchy above using @(.)@ from the @Prelude@, and you can
    use any element of the hierarchy as any type it linked to above it.
    .
    The result is their lowest upper bound in the hierarchy (or an error if that bound doesn'\''t exist).
    .
    For instance:
    .
    * You can use any '\''Traversal'\'' as a '\''Fold'\'' or as a '\''Setter'\''.
    .
    * The composition of a '\''Traversal'\'' and a '\''Getter'\'' yields a '\''Fold'\''.
    .
    /Minimizing Dependencies/
    .
    If you want to provide lenses and traversals for your own types in your own libraries, then you
    can do so without incurring a dependency on this (or any other) lens package at all.
    .
    /e.g./ for a data type:
    .
    > data Foo a = Foo Int Int a
    .
    You can define lenses such as
    .
    > -- bar :: Lens'\'' (Foo a) Int
    > bar :: Functor f => (Int -> f Int) -> Foo a -> f (Foo a)
    > bar f (Foo a b c) = fmap (\a'\'' -> Foo a'\'' b c) (f a)
    .
    > -- quux :: Lens (Foo a) (Foo b) a b
    > quux :: Functor f => (a -> f b) -> Foo a -> f (Foo b)
    > quux f (Foo a b c) = fmap (Foo a b) (f c)
    .
    without the need to use any type that isn'\''t already defined in the @Prelude@.
    .
    And you can define a traversal of multiple fields with '\''Control.Applicative.Applicative'\'':
    .
    > -- traverseBarAndBaz :: Traversal'\'' (Foo a) Int
    > traverseBarAndBaz :: Applicative f => (Int -> f Int) -> Foo a -> f (Foo a)
    > traverseBarAndBaz f (Foo a b c) = Foo <$> f a <*> f b <*> pure c
    .
    What is provided in this library is a number of stock lenses and traversals for
    common haskell types, a wide array of combinators for working them, and more
    exotic functionality, (/e.g./ getters, setters, indexed folds, isomorphisms).
category: Data, Lenses, Generics
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Exception.Lens Control.Lens Control.Lens.At
    Control.Lens.Combinators Control.Lens.Cons Control.Lens.Each
    Control.Lens.Empty Control.Lens.Equality Control.Lens.Extras
    Control.Lens.Fold Control.Lens.Getter Control.Lens.Indexed
    Control.Lens.Internal Control.Lens.Internal.Bazaar
    Control.Lens.Internal.ByteString Control.Lens.Internal.Coerce
    Control.Lens.Internal.Context Control.Lens.Internal.Deque
    Control.Lens.Internal.Exception Control.Lens.Internal.FieldTH
    Control.Lens.Internal.PrismTH Control.Lens.Internal.Fold
    Control.Lens.Internal.Getter Control.Lens.Internal.Indexed
    Control.Lens.Internal.Instances Control.Lens.Internal.Iso
    Control.Lens.Internal.Level Control.Lens.Internal.List
    Control.Lens.Internal.Magma Control.Lens.Internal.Prism
    Control.Lens.Internal.Review Control.Lens.Internal.Setter
    Control.Lens.Internal.TH Control.Lens.Internal.Zoom
    Control.Lens.Iso Control.Lens.Lens Control.Lens.Level
    Control.Lens.Operators Control.Lens.Plated Control.Lens.Prism
    Control.Lens.Reified Control.Lens.Review Control.Lens.Setter
    Control.Lens.TH Control.Lens.Traversal Control.Lens.Tuple
    Control.Lens.Type Control.Lens.Wrapped Control.Lens.Zoom
    Control.Monad.Error.Lens Control.Parallel.Strategies.Lens
    Control.Seq.Lens Data.Array.Lens Data.Bits.Lens
    Data.ByteString.Lens Data.ByteString.Strict.Lens
    Data.ByteString.Lazy.Lens Data.Complex.Lens Data.Data.Lens
    Data.Dynamic.Lens Data.HashSet.Lens Data.IntSet.Lens Data.List.Lens
    Data.Map.Lens Data.Sequence.Lens Data.Set.Lens Data.Text.Lens
    Data.Text.Strict.Lens Data.Text.Lazy.Lens Data.Tree.Lens
    Data.Typeable.Lens Data.Vector.Lens Data.Vector.Generic.Lens
    Generics.Deriving.Lens GHC.Generics.Lens System.Exit.Lens
    System.FilePath.Lens System.IO.Error.Lens Language.Haskell.TH.Lens
    Numeric.Lens
hidden-modules: Paths_lens
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.10.2/lens-4.12.3
library-dirs: /usr/local/lib/cabal/ghc-7.10.2/lens-4.12.3
              /usr/local/lib
data-dir: /usr/local/share/cabal/ghc-7.10.2/lens-4.12.3
hs-libraries: HSlens-4.12.3-HrIy992mtzN5wFUKQZBmkf
include-dirs: /usr/local/include
depends:
    array-0.5.1.0-d4206b835b96b5079d918fa1eab1a9a8
    base-4.8.1.0-b8b97b99f1626bb4a12880f48ca36184
    base-orphans-0.4.4-61f87fbe40b70a96b4f01742198bd89e
    bifunctors-5-2b5356087f946c95acfd1c689bb6a6a9
    bytestring-0.10.6.0-3316235c3eca5b6c3be96ecdc7d31040
    comonad-4.2.7.2-7dee90f058b530c7fd125fc1d8f7fafe
    containers-0.5.6.2-038ff4498ef87a6c587d93cd99a6573b
    contravariant-1.3.2-ce56e69c83e6634078c4687332c6f646
    distributive-0.4.4-8ccf7d9b4dba827f6bbdf2f9c6ea65a1
    exceptions-0.8.0.2-b08bd0de7dff383d124cad3f4c34eddd
    filepath-1.4.0.0-8fee9c13b5e42926cc01f6aa7c403c4b
    free-4.12.1-d59ccd286da2cb84c0fcfa238af7ec44
    ghc-prim-0.4.0.0-af16264bc80979d06e37ac63e3ba9a21
    hashable-1.2.3.3-8f170cf3be214ecb17aa999ac01e25b9
    kan-extensions-4.2.2-9f154547c3269de947799753fcdd8d5d
    mtl-2.2.1-5cf332b11edb88a6040af20fd6a58acb
    parallel-3.2.0.6-8d3b701e5e226adf3c5602966a8a78d7
    profunctors-5.1.1-735a94eb29dddc53b423b7a49a61618e
    reflection-2-e399a859a760dc2259b0c5f750f24454
    semigroupoids-5.0.0.3-fbc72ed4805b06eae441ee9bd856821c
    semigroups-0.16.2.2-1ca08599864b70ede24d88606eededa0
    tagged-0.8.1-8fb7724b78ef88e44ca8950c77a173f6
    template-haskell-2.10.0.0-08b8877239099034286979627d937e79
    text-1.2.1.3-7b7b9ddb2dfcabed4e37e6b2f8cdc5f5
    transformers-0.4.2.0-21dcbf13c43f5d8cf6a1f54dee6c5bff
    transformers-compat-0.4.0.4-3ca5cbcec233c17da785d5f27705643c
    unordered-containers-0.2.5.1-f06a187b7e838c69d874badd31102fe1
    vector-0.10.12.3-df22e243cd37291cebd65584b0ee856f
    void-0.7-30fafbfde0a5a4b9a359326d9e6c8b47
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.10.2/lens-4.12.3/html/lens.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.10.2/lens-4.12.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
